import { ConnectStatus, CustomeSocket, SocketSettings } from "../types/socket";
import { ref } from "vue";
import { useInjector, useState } from "vue-vulcan";
import { CUSTOME_SOCKET, SOCKET_SETTINGS } from "../communication/token";

export function useSocket<S = any>() {
  const [status, setStatus]  = useState<ConnectStatus>('ready');
  const [currentMsg, setMsg] = useState<S>(null);
  const customeSocket        = useInjector<CustomeSocket<S>>(CUSTOME_SOCKET, 'optional');
  const socketSettings       = useInjector<SocketSettings>(SOCKET_SETTINGS, 'optional');

  let ws: CustomeSocket<S>;
  if(customeSocket) ws = customeSocket;  

  const connect = (url?: string) => {
    if(customeSocket) {
      ws.connect(url)
    } else {
      ws = new WebSocket(url) as unknown as CustomeSocket<S>
    }
    ws.addEventListener('message', event => setMsg(event.data));
    ws.addEventListener('open', () => setStatus('opening'));
    ws.addEventListener('open', () => socketSettings.heartData && startHeartConnect());    
    ws.addEventListener('close', () => setStatus('closed'));
    ws.addEventListener('error', () => {
      setStatus('onerror'); 
      reconnect(url);
    });
  }

  // 心跳链接  
  const startHeartConnect = () => {
    const time = socketSettings.heartInterval;
    setInterval( () => ws.send(socketSettings.heartData), time && time >= 3000 ? time : 5000 )    
  }
 
  // 重连功能
  const brokenTime = ref(0);
  const limit = socketSettings.retryLimit || 5;
  const reconnect = (url: string) => {
    brokenTime.value ++;    
    if(brokenTime.value > limit) {
      ws.close();
    } else {
      setStatus('reconnect');
      setTimeout( () => connect(url), brokenTime.value*1000 );
    }    
  }

  return {
    currentMsg,
    status,
    connect,
    send: ws.send,
    close: ws.close
  }
}