import { watch } from "vue";
import { BehaviorSubject } from "rxjs";
import { useRequest, useState } from "vue-vulcan";

interface ChannelData {
  channel_id: string;
  agora_token: string;
  members: string[];
}

export function useChannelStore() {
  const [currentChannel, setCurrent]   = useState<ChannelData>(null);
  const [channelInfo, request]         = useRequest<ChannelData>('/getAgoraToken', {auto: false});
  const ready$ = new BehaviorSubject<boolean>(false);

  const createChannel = () => {
    return request()
  }  

  const joinCallingChannel = (id: string) => {
    request({channel_id: id})
  }

  const onReady = ( callback: () => void) => {
    ready$.subscribe( r => { r && callback() })
  }

  watch(channelInfo, val => {    
    setCurrent(val);    
  })


  return {
    currentChannel,
    joinCallingChannel,
    createChannel,
    onReady
  }
}