import './app.less';
import { authorize,  } from '@tarojs/taro';
import { createApp } from 'vue';
import { useCustomeRequest } from './hooks/http/useCustomeRequest';
import { useProviders } from 'vue-vulcan';
import { useRequestOption } from './hooks/http/useRequestOption';
import { useAuthCheck } from './hooks/user/useAuthCheck';
import { useHttpIntercept } from './hooks/http/useHttpIntercept';
import { useCustomeStorage } from './hooks/storage/useCustomeStorage';
import { useAuthData } from 'any-hooks/auth/useAuthData';
import { useCustomeSocket } from './hooks/socket/useCustomeSocket';
import { useSocketSetting } from './hooks/socket/useSocketSettings';
import { useCallCenter } from 'any-hooks/communication/useCallCenter';
import { useChannelStore } from 'any-hooks/communication/useChannelStore';
import { useNetSocketCenter } from 'any-hooks/communication/useNetSocketCenter';
import { useCallerListener } from './hooks/call/useCallerListener';

const App = createApp({
  onShow () {},  
  setup() {        
    useProviders(     
      useCustomeStorage,  //自定义基于taro的storage的接口，覆盖useState默认的sessionStorage/localStorage方法
      useCustomeRequest,  //自定义基于taro.request的请求接口，覆盖useRequet默认的fetch方法
      useAuthData,        //全局的用户权限数据hook      
      useHttpIntercept,   //提供http请求拦截器
      useRequestOption,   //提供http请求配置项  
      useSocketSetting,   //提供小程序socket通讯的全局配置 
      useCustomeSocket,   //自定义基于taro的socket通讯接口，覆盖useSocket默认的websokcet   
      useNetSocketCenter, //全局的socket连接中心       
      useChannelStore,    //全局的频道信息
      useCallCenter,      //全局的多人呼叫,
      useCallerListener   //在整个APP生命周期内监听远程联系人的呼叫请求
    );
    authorize({ scope: 'scope.camera' });
    useAuthCheck();    
  }
})

export default App
